searchData={"items":[{"type":"extras","title":"Scrivener.List","doc":"# Scrivener.List\n[![Hex Version](http://img.shields.io/hexpm/v/scrivener_list.svg?style=flat)](https://hex.pm/packages/scrivener_list)\n[![Hex docs](http://img.shields.io/badge/hex.pm-docs-green.svg?style=flat)](https://hexdocs.pm/scrivener_list)\n\n[Scrivener.List](https://hex.pm/packages/scrivener_list) is a Scrivener compatible extension that\nallows the pagination of a list of elements.","ref":"readme.html"},{"type":"extras","title":"Features - Scrivener.List","doc":"1.  Scrivener.List extends the protocol `Scrivener.Paginater.paginate/2` from the [scrivener](https://github.com/drewolson/scrivener) library.\n1.  Scrivener.List also extends the function `MyApp.Repo.paginate/2` from the [scrivener_ecto](https://github.com/drewolson/scrivener_ecto) library.\n\nUsing the second feature is entirely optional. It's provided as a convenience where the [scrivener_ecto](https://github.com/drewolson/scrivener_ecto)\nlibrary is also being used in the project and gives access to the\npre-configured `MyApp.Repo` module.","ref":"readme.html#features"},{"type":"extras","title":"Usage - Scrivener.List","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"1. Usage without a Repo module - Scrivener.List","doc":"```elixir\nScrivener.paginate(list, config)\n```","ref":"readme.html#1-usage-without-a-repo-module"},{"type":"extras","title":"Arguments (without a repo) - Scrivener.List","doc":"-   ```list```: A list of elements to be paginated\n\n-   ```config```: A configuration object with the pagination details.\n    Can be in any of the following formats:\n    -   ```%{page: page_number, page_size: page_size}``` (map)\n    -   ```[page: page_number, page_size: page_size]``` (Keyword.t)\n    -   ```%Scrivener.Config{page_number: page_number, page_size: page_size}``` (Scrivener.Config.t)\n\n`max_page_size` **cannot** be configured with method 1.","ref":"readme.html#arguments-without-a-repo"},{"type":"extras","title":"Examples - Scrivener.List","doc":"```elixir\ndef index(conn, params) do\n  config = maybe_put_default_config(params)\n\n  page =\n    [\"C#\", \"C++\", \"Clojure\", \"Elixir\", \"Erlang\", \"Go\", \"JAVA\", \"JavaScript\", \"Lisp\",\n      \"PHP\", \"Perl\", \"Python\", \"Ruby\", \"Rust\", \"SQL\"]\n    |> Enum.map(&(&1 <> \"  \" <> \"language\"))\n    |> Scrivener.paginate(config)\n\n  render conn, :index,\n    people: page.entries,\n    page_number: page.page_number,\n    page_size: page.page_size,\n    total_pages: page.total_pages,\n    total_entries: page.total_entries\nend\n\ndefp maybe_put_default_config(%{page: page_number, page_size: page_size} = params), do: params\ndefp maybe_put_default_config(_params), do: %Scrivener.Config{page_number: 1, page_size: 10}\n```\n\n```elixir\nlist = [\"C#\", \"C++\", \"Clojure\", \"Elixir\", \"Erlang\", \"Go\", \"JAVA\", \"JavaScript\", \"Lisp\",\n        \"PHP\", \"Perl\", \"Python\", \"Ruby\", \"Rust\", \"SQL\"]\n\nScrivener.paginate(list, %Scrivener.Config{page_number: 1, page_size: 4}) # %Scrivener.Config{}\nScrivener.paginate(list, page: 1, page_size: 4) # keyword list\nScrivener.paginate(list, %{page: 1, page_size: 4}) # map\nScrivener.paginate(list, %{page: 1}) # map with only page number (page_size defaults to 10)\n```","ref":"readme.html#examples"},{"type":"extras","title":"2. Usage with a Repo module - Scrivener.List","doc":"Usage without a Repo is entirely optional and is added to `Scrivener.List` for convenience.\nFirstly, see [Scrivener.Ecto](https://github.com/drewolson/scrivener_ecto) and configure the `MyApp.Repo` module.","ref":"readme.html#2-usage-with-a-repo-module"},{"type":"extras","title":"Example Repo configuration - Scrivener.List","doc":"```elixir\ndefmodule MyApp.Repo do\n  use Ecto.Repo,\n    otp_app: :my_app,\n    adapter: Ecto.Adapters.Postgres\n  use Scrivener,\n    page_size: 10,\n    max_page_size: 100\nend\n```\n\n```elixir\nMyApp.Repo.paginate(list, config)\n```","ref":"readme.html#example-repo-configuration"},{"type":"extras","title":"Arguments (with a repo) - Scrivener.List","doc":"-   ```list```: A list of elements to be paginated\n\n-   ```config```: A configuration object with the pagination details.\n    Can be in any of the following formats:\n    -   ```%{page: page_number, page_size: page_size}``` (map)\n    -   ```[page: page_number, page_size: page_size]``` (Keyword.t)\n\n`max_page_size` **can** be configured with method 1. See [Scrivener.Ecto](https://github.com/drewolson/scrivener_ecto).","ref":"readme.html#arguments-with-a-repo"},{"type":"extras","title":"Example - Scrivener.List","doc":"Example based on [scrivener_ecto](https://github.com/drewolson/scrivener_ecto) readme.\n\n```elixir\ndef index(conn, params) do\n  %{age: age, name: name} = params[\"search\"]\n\n  page = MyApp.Person\n  |> where([p], p.age > ^age)\n  |> order_by([p], desc: p.age)\n  |> preload(:friends)\n  |> MyApp.Repo.all()\n  |> Enum.filter(fn(person) -> person.data.friend.name = name end)\n  |> MyApp.Repo.paginate(params)\n\n  render conn, :index,\n    people: page.entries,\n    page_number: page.page_number,\n    page_size: page.page_size,\n    total_pages: page.total_pages,\n    total_entries: page.total_entries\nend\n```","ref":"readme.html#example"},{"type":"extras","title":"Installation - Scrivener.List","doc":"Add [scrivener_list](https://hex.pm/packages/scrivener_list) to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:scrivener_list, \"~> 2.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Tests - Scrivener.List","doc":"```shell\nMIX_ENV=test mix test\n```","ref":"readme.html#tests"},{"type":"extras","title":"Acknowledgements - Scrivener.List","doc":"The introduction of the [protocol](http://blog.drewolson.org/extensible-design-with-protocols/)\nfor scrivener enabled the separation of this package into it's own\nrepository.","ref":"readme.html#acknowledgements"},{"type":"extras","title":"Licence - Scrivener.List","doc":"MIT","ref":"readme.html#licence"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}